#ifdef GET_SME_BUILTINS
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za32_s32_vg1x2, "vUiq8iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za32_s32_vg1x4, "vUiq16iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za32_u32_vg1x2, "vUiq8Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za32_u32_vg1x4, "vUiq16Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za64_s64_vg1x2, "vUiq4Wiq2Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za64_s64_vg1x4, "vUiq8Wiq2Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za64_u64_vg1x2, "vUiq4UWiq2UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_single_za64_u64_vg1x4, "vUiq8UWiq2UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_za32_s32_vg1x2, "vUiq8iq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_za32_s32_vg1x4, "vUiq16iq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_za32_u32_vg1x2, "vUiq8Uiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_za32_u32_vg1x4, "vUiq16Uiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_write_za64_s64_vg1x2, "vUiq4Wiq4Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_za64_s64_vg1x4, "vUiq8Wiq8Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_za64_u64_vg1x2, "vUiq4UWiq4UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_write_za64_u64_vg1x4, "vUiq8UWiq8UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_za16_bf16_vg1x2, "vUiq16y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svadd_za16_bf16_vg1x4, "vUiq32y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svadd_za16_f16_vg1x2, "vUiq16h", "n", "sme-f16f16|sme-f8f16")
TARGET_BUILTIN(__builtin_sme_svadd_za16_f16_vg1x4, "vUiq32h", "n", "sme-f16f16|sme-f8f16")
TARGET_BUILTIN(__builtin_sme_svadd_za32_f32_vg1x2, "vUiq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za32_f32_vg1x4, "vUiq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za32_s32_vg1x2, "vUiq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za32_s32_vg1x4, "vUiq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za32_u32_vg1x2, "vUiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za32_u32_vg1x4, "vUiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svadd_za64_f64_vg1x2, "vUiq4d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svadd_za64_f64_vg1x4, "vUiq8d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svadd_za64_s64_vg1x2, "vUiq4Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_za64_s64_vg1x4, "vUiq8Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_za64_u64_vg1x2, "vUiq4UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svadd_za64_u64_vg1x4, "vUiq8UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svaddha_za32_s32_m, "vIUWiq16bq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svaddha_za32_u32_m, "vIUWiq16bq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svaddha_za64_s64_m, "vIUWiq16bq16bq2Wi", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svaddha_za64_u64_m, "vIUWiq16bq16bq2UWi", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svaddva_za32_s32_m, "vIUWiq16bq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svaddva_za32_u32_m, "vIUWiq16bq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svaddva_za64_s64_m, "vIUWiq16bq16bq2Wi", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svaddva_za64_u64_m, "vIUWiq16bq16bq2UWi", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svbmopa_za32_s32_m, "vIUWiq16bq16bq4iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svbmopa_za32_u32_m, "vIUWiq16bq16bq4Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svbmops_za32_s32_m, "vIUWiq16bq16bq4iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svbmops_za32_u32_m, "vIUWiq16bq16bq4Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svcntsb, "UWiv", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svcntsd, "UWiv", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svcntsh, "UWiv", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svcntsw, "UWiv", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_bf16_vg1x2, "vUiq16yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_bf16_vg1x4, "vUiq32yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_f16_vg1x2, "vUiq16hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_f16_vg1x4, "vUiq32hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_s16_vg1x2, "vUiq16sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_s16_vg1x4, "vUiq32sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_s8_vg1x2, "vUiq32Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_s8_vg1x4, "vUiq64Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_u16_vg1x2, "vUiq16Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_u16_vg1x4, "vUiq32Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_u8_vg1x2, "vUiq32Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za32_u8_vg1x4, "vUiq64Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za64_s16_vg1x2, "vUiq16sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za64_s16_vg1x4, "vUiq32sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za64_u16_vg1x2, "vUiq16Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_lane_za64_u16_vg1x4, "vUiq32Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_bf16_vg1x2, "vUiq16yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_bf16_vg1x4, "vUiq32yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_f16_vg1x2, "vUiq16hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_f16_vg1x4, "vUiq32hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_s16_vg1x2, "vUiq16sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_s16_vg1x4, "vUiq32sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_s8_vg1x2, "vUiq32Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_s8_vg1x4, "vUiq64Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_u16_vg1x2, "vUiq16Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_u16_vg1x4, "vUiq32Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_u8_vg1x2, "vUiq32Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za32_u8_vg1x4, "vUiq64Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_single_za64_s16_vg1x2, "vUiq16sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_single_za64_s16_vg1x4, "vUiq32sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_single_za64_u16_vg1x2, "vUiq16Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_single_za64_u16_vg1x4, "vUiq32Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_za32_bf16_vg1x2, "vUiq16yq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_bf16_vg1x4, "vUiq32yq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_f16_vg1x2, "vUiq16hq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_f16_vg1x4, "vUiq32hq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_s16_vg1x2, "vUiq16sq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_s16_vg1x4, "vUiq32sq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_s8_vg1x2, "vUiq32Scq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_s8_vg1x4, "vUiq64Scq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_u16_vg1x2, "vUiq16Usq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_u16_vg1x4, "vUiq32Usq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_u8_vg1x2, "vUiq32Ucq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za32_u8_vg1x4, "vUiq64Ucq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svdot_za64_s16_vg1x2, "vUiq16sq16s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_za64_s16_vg1x4, "vUiq32sq32s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_za64_u16_vg1x2, "vUiq16Usq16Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svdot_za64_u16_vg1x4, "vUiq32Usq32Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svld1_hor_vnum_za128, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_vnum_za16, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_vnum_za32, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_vnum_za64, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_vnum_za8, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_za128, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_za16, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_za32, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_za64, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_hor_za8, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_vnum_za128, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_vnum_za16, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_vnum_za32, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_vnum_za64, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_vnum_za8, "vIUWiUiq16bvC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_za128, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_za16, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_za32, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_za64, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svld1_ver_za8, "vIUWiUiq16bvC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svldr_vnum_za, "vUivC*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svldr_za, "vUivC*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svldr_zt, "vIUWivC*", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_bf16, "q8yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_bf16_x2, "q16yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_bf16_x4, "q32yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f16, "q8hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f16_x2, "q16hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f16_x4, "q32hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f32, "q4fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f32_x2, "q8fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_f32_x4, "q16fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s16, "q8sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s16_x2, "q16sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s16_x4, "q32sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s32, "q4iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s32_x2, "q8iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s32_x4, "q16iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s8, "q16ScIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s8_x2, "q32ScIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_s8_x4, "q64ScIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u16, "q8UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u16_x2, "q16UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u16_x4, "q32UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u32, "q4UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u32_x2, "q8UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u32_x4, "q16UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u8, "q16UcIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u8_x2, "q32UcIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti2_lane_zt_u8_x4, "q64UcIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_bf16, "q8yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_bf16_x2, "q16yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_bf16_x4, "q32yIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f16, "q8hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f16_x2, "q16hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f16_x4, "q32hIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f32, "q4fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f32_x2, "q8fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_f32_x4, "q16fIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s16, "q8sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s16_x2, "q16sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s16_x4, "q32sIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s32, "q4iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s32_x2, "q8iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s32_x4, "q16iIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s8, "q16ScIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_s8_x2, "q32ScIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u16, "q8UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u16_x2, "q16UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u16_x4, "q32UsIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u32, "q4UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u32_x2, "q8UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u32_x4, "q16UiIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u8, "q16UcIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svluti4_lane_zt_u8_x2, "q32UcIUWiq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za16_bf16_vg1x2, "vUiq16yq8yIUWi", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za16_bf16_vg1x4, "vUiq32yq8yIUWi", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za16_f16_vg1x2, "vUiq16hq8hIUWi", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za16_f16_vg1x4, "vUiq32hq8hIUWi", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_bf16_vg2x1, "vUiq8yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_bf16_vg2x2, "vUiq16yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_bf16_vg2x4, "vUiq32yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_f16_vg2x1, "vUiq8hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_f16_vg2x2, "vUiq16hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_f16_vg2x4, "vUiq32hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_f32_vg1x2, "vUiq8fq4fIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_f32_vg1x4, "vUiq16fq4fIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s16_vg2x1, "vUiq8sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s16_vg2x2, "vUiq16sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s16_vg2x4, "vUiq32sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s8_vg4x1, "vUiq16Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s8_vg4x2, "vUiq32Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_s8_vg4x4, "vUiq64Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u16_vg2x1, "vUiq8Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u16_vg2x2, "vUiq16Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u16_vg2x4, "vUiq32Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u8_vg4x1, "vUiq16Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u8_vg4x2, "vUiq32Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za32_u8_vg4x4, "vUiq64Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_f64_vg1x2, "vUiq4dq2dIUWi", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_f64_vg1x4, "vUiq8dq2dIUWi", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_s16_vg4x1, "vUiq8sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_s16_vg4x2, "vUiq16sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_s16_vg4x4, "vUiq32sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_u16_vg4x1, "vUiq8Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_u16_vg4x2, "vUiq16Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_lane_za64_u16_vg4x4, "vUiq32Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za16_bf16_vg1x2, "vUiq16yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_single_za16_bf16_vg1x4, "vUiq32yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_single_za16_f16_vg1x2, "vUiq16hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_single_za16_f16_vg1x4, "vUiq32hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_bf16_vg2x2, "vUiq16yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_bf16_vg2x4, "vUiq32yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_f16_vg2x2, "vUiq16hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_f16_vg2x4, "vUiq32hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_f32_vg1x2, "vUiq8fq4f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_f32_vg1x4, "vUiq16fq4f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_s16_vg2x2, "vUiq16sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_s16_vg2x4, "vUiq32sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_s8_vg4x2, "vUiq32Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_s8_vg4x4, "vUiq64Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_u16_vg2x2, "vUiq16Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_u16_vg2x4, "vUiq32Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_u8_vg4x2, "vUiq32Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za32_u8_vg4x4, "vUiq64Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_f64_vg1x2, "vUiq4dq2d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_f64_vg1x4, "vUiq8dq2d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_s16_vg4x2, "vUiq16sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_s16_vg4x4, "vUiq32sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_u16_vg4x2, "vUiq16Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_single_za64_u16_vg4x4, "vUiq32Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za16_bf16_vg1x2, "vUiq16yq16y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_za16_bf16_vg1x4, "vUiq32yq32y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmla_za16_f16_vg1x2, "vUiq16hq16h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_za16_f16_vg1x4, "vUiq32hq32h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmla_za32_bf16_vg2x1, "vUiq8yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_bf16_vg2x2, "vUiq16yq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_bf16_vg2x4, "vUiq32yq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_f16_vg2x1, "vUiq8hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_f16_vg2x2, "vUiq16hq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_f16_vg2x4, "vUiq32hq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_f32_vg1x2, "vUiq8fq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_f32_vg1x4, "vUiq16fq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s16_vg2x1, "vUiq8sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s16_vg2x2, "vUiq16sq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s16_vg2x4, "vUiq32sq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s8_vg4x1, "vUiq16Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s8_vg4x2, "vUiq32Scq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_s8_vg4x4, "vUiq64Scq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u16_vg2x1, "vUiq8Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u16_vg2x2, "vUiq16Usq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u16_vg2x4, "vUiq32Usq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u8_vg4x1, "vUiq16Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u8_vg4x2, "vUiq32Ucq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za32_u8_vg4x4, "vUiq64Ucq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmla_za64_f64_vg1x2, "vUiq4dq4d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_f64_vg1x4, "vUiq8dq8d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_s16_vg4x1, "vUiq8sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_s16_vg4x2, "vUiq16sq16s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_s16_vg4x4, "vUiq32sq32s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_u16_vg4x1, "vUiq8Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_u16_vg4x2, "vUiq16Usq16Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmla_za64_u16_vg4x4, "vUiq32Usq32Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za16_bf16_vg1x2, "vUiq16yq8yIUWi", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za16_bf16_vg1x4, "vUiq32yq8yIUWi", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za16_f16_vg1x2, "vUiq16hq8hIUWi", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za16_f16_vg1x4, "vUiq32hq8hIUWi", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_bf16_vg2x1, "vUiq8yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_bf16_vg2x2, "vUiq16yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_bf16_vg2x4, "vUiq32yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_f16_vg2x1, "vUiq8hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_f16_vg2x2, "vUiq16hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_f16_vg2x4, "vUiq32hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_f32_vg1x2, "vUiq8fq4fIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_f32_vg1x4, "vUiq16fq4fIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s16_vg2x1, "vUiq8sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s16_vg2x2, "vUiq16sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s16_vg2x4, "vUiq32sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s8_vg4x1, "vUiq16Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s8_vg4x2, "vUiq32Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_s8_vg4x4, "vUiq64Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u16_vg2x1, "vUiq8Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u16_vg2x2, "vUiq16Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u16_vg2x4, "vUiq32Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u8_vg4x1, "vUiq16Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u8_vg4x2, "vUiq32Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za32_u8_vg4x4, "vUiq64Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_f64_vg1x2, "vUiq4dq2dIUWi", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_f64_vg1x4, "vUiq8dq2dIUWi", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_s16_vg4x1, "vUiq8sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_s16_vg4x2, "vUiq16sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_s16_vg4x4, "vUiq32sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_u16_vg4x1, "vUiq8Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_u16_vg4x2, "vUiq16Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_lane_za64_u16_vg4x4, "vUiq32Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za16_bf16_vg1x2, "vUiq16yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_single_za16_bf16_vg1x4, "vUiq32yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_single_za16_f16_vg1x2, "vUiq16hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_single_za16_f16_vg1x4, "vUiq32hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_bf16_vg2x2, "vUiq16yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_bf16_vg2x4, "vUiq32yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_f16_vg2x2, "vUiq16hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_f16_vg2x4, "vUiq32hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_f32_vg1x2, "vUiq8fq4f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_f32_vg1x4, "vUiq16fq4f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_s16_vg2x2, "vUiq16sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_s16_vg2x4, "vUiq32sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_s8_vg4x2, "vUiq32Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_s8_vg4x4, "vUiq64Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_u16_vg2x2, "vUiq16Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_u16_vg2x4, "vUiq32Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_u8_vg4x2, "vUiq32Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za32_u8_vg4x4, "vUiq64Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_f64_vg1x2, "vUiq4dq2d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_f64_vg1x4, "vUiq8dq2d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_s16_vg4x2, "vUiq16sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_s16_vg4x4, "vUiq32sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_u16_vg4x2, "vUiq16Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_single_za64_u16_vg4x4, "vUiq32Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za16_bf16_vg1x2, "vUiq16yq16y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_za16_bf16_vg1x4, "vUiq32yq32y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmls_za16_f16_vg1x2, "vUiq16hq16h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_za16_f16_vg1x4, "vUiq32hq32h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmls_za32_bf16_vg2x1, "vUiq8yq8y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_bf16_vg2x2, "vUiq16yq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_bf16_vg2x4, "vUiq32yq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_f16_vg2x1, "vUiq8hq8h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_f16_vg2x2, "vUiq16hq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_f16_vg2x4, "vUiq32hq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_f32_vg1x2, "vUiq8fq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_f32_vg1x4, "vUiq16fq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s16_vg2x1, "vUiq8sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s16_vg2x2, "vUiq16sq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s16_vg2x4, "vUiq32sq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s8_vg4x1, "vUiq16Scq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s8_vg4x2, "vUiq32Scq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_s8_vg4x4, "vUiq64Scq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u16_vg2x1, "vUiq8Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u16_vg2x2, "vUiq16Usq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u16_vg2x4, "vUiq32Usq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u8_vg4x1, "vUiq16Ucq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u8_vg4x2, "vUiq32Ucq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za32_u8_vg4x4, "vUiq64Ucq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmls_za64_f64_vg1x2, "vUiq4dq4d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_f64_vg1x4, "vUiq8dq8d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_s16_vg4x1, "vUiq8sq8s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_s16_vg4x2, "vUiq16sq16s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_s16_vg4x4, "vUiq32sq32s", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_u16_vg4x1, "vUiq8Usq8Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_u16_vg4x2, "vUiq16Usq16Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmls_za64_u16_vg4x4, "vUiq32Usq32Us", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmopa_za16_bf16_m, "vIUWiq16bq16bq8yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmopa_za16_f16_m, "vIUWiq16bq16bq8hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_bf16_m, "vIUWiq16bq16bq8yq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_f16_m, "vIUWiq16bq16bq8hq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_f32_m, "vIUWiq16bq16bq4fq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_s16_m, "vIUWiq16bq16bq8sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_s8_m, "vIUWiq16bq16bq16Scq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_u16_m, "vIUWiq16bq16bq8Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmopa_za32_u8_m, "vIUWiq16bq16bq16Ucq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmopa_za64_f64_m, "vIUWiq16bq16bq2dq2d", "n", "sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmopa_za64_s16_m, "vIUWiq16bq16bq8sq8s", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmopa_za64_u16_m, "vIUWiq16bq16bq8Usq8Us", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmops_za16_bf16_m, "vIUWiq16bq16bq8yq8y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svmops_za16_f16_m, "vIUWiq16bq16bq8hq8h", "n", "sme-f16f16")
TARGET_BUILTIN(__builtin_sme_svmops_za32_bf16_m, "vIUWiq16bq16bq8yq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmops_za32_f16_m, "vIUWiq16bq16bq8hq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmops_za32_f32_m, "vIUWiq16bq16bq4fq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmops_za32_s16_m, "vIUWiq16bq16bq8sq8s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmops_za32_s8_m, "vIUWiq16bq16bq16Scq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmops_za32_u16_m, "vIUWiq16bq16bq8Usq8Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svmops_za32_u8_m, "vIUWiq16bq16bq16Ucq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svmops_za64_f64_m, "vIUWiq16bq16bq2dq2d", "n", "sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svmops_za64_s16_m, "vIUWiq16bq16bq8sq8s", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svmops_za64_u16_m, "vIUWiq16bq16bq8Usq8Us", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_bf16_m, "q8yq8yq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_f16_m, "q8hq8hq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_f32_m, "q4fq4fq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_f64_m, "q2dq2dq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_s16_m, "q8sq8sq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_s32_m, "q4iq4iq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_s64_m, "q2Wiq2Wiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_s8_m, "q16Scq16Scq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_u16_m, "q8Usq8Usq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_u32_m, "q4Uiq4Uiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_u64_m, "q2UWiq2UWiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za128_u8_m, "q16Ucq16Ucq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_bf16_m, "q8yq8yq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_bf16_vg2, "q16yIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_bf16_vg4, "q32yIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_f16_m, "q8hq8hq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_f16_vg2, "q16hIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_f16_vg4, "q32hIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_s16_m, "q8sq8sq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_s16_vg2, "q16sIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_s16_vg4, "q32sIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_u16_m, "q8Usq8Usq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_u16_vg2, "q16UsIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za16_u16_vg4, "q32UsIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_f32_m, "q4fq4fq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_f32_vg2, "q8fIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_f32_vg4, "q16fIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_s32_m, "q4iq4iq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_s32_vg2, "q8iIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_s32_vg4, "q16iIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_u32_m, "q4Uiq4Uiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_u32_vg2, "q8UiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za32_u32_vg4, "q16UiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_f64_m, "q2dq2dq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_f64_vg2, "q4dIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_f64_vg4, "q8dIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_s64_m, "q2Wiq2Wiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_s64_vg2, "q4WiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_s64_vg4, "q8WiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_u64_m, "q2UWiq2UWiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_u64_vg2, "q4UWiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za64_u64_vg4, "q8UWiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_s8_m, "q16Scq16Scq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_s8_vg2, "q32ScIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_s8_vg4, "q64ScIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_u8_m, "q16Ucq16Ucq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_u8_vg2, "q32UcIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_hor_za8_u8_vg4, "q64UcIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_bf16_m, "q8yq8yq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_f16_m, "q8hq8hq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_f32_m, "q4fq4fq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_f64_m, "q2dq2dq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_s16_m, "q8sq8sq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_s32_m, "q4iq4iq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_s64_m, "q2Wiq2Wiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_s8_m, "q16Scq16Scq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_u16_m, "q8Usq8Usq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_u32_m, "q4Uiq4Uiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_u64_m, "q2UWiq2UWiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za128_u8_m, "q16Ucq16Ucq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_bf16_m, "q8yq8yq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_bf16_vg2, "q16yIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_bf16_vg4, "q32yIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_f16_m, "q8hq8hq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_f16_vg2, "q16hIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_f16_vg4, "q32hIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_s16_m, "q8sq8sq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_s16_vg2, "q16sIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_s16_vg4, "q32sIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_u16_m, "q8Usq8Usq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_u16_vg2, "q16UsIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za16_u16_vg4, "q32UsIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_f32_m, "q4fq4fq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_f32_vg2, "q8fIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_f32_vg4, "q16fIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_s32_m, "q4iq4iq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_s32_vg2, "q8iIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_s32_vg4, "q16iIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_u32_m, "q4Uiq4Uiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_u32_vg2, "q8UiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za32_u32_vg4, "q16UiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_f64_m, "q2dq2dq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_f64_vg2, "q4dIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_f64_vg4, "q8dIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_s64_m, "q2Wiq2Wiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_s64_vg2, "q4WiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_s64_vg4, "q8WiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_u64_m, "q2UWiq2UWiq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_u64_vg2, "q4UWiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za64_u64_vg4, "q8UWiIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_s8_m, "q16Scq16Scq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_s8_vg2, "q32ScIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_s8_vg4, "q64ScIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_u8_m, "q16Ucq16Ucq16bIUWiUi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_u8_vg2, "q32UcIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_ver_za8_u8_vg4, "q64UcIUWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_bf16_vg1x2, "q16yUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_bf16_vg1x4, "q32yUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_f16_vg1x2, "q16hUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_f16_vg1x4, "q32hUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_s16_vg1x2, "q16sUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_s16_vg1x4, "q32sUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_u16_vg1x2, "q16UsUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za16_u16_vg1x4, "q32UsUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_f32_vg1x2, "q8fUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_f32_vg1x4, "q16fUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_s32_vg1x2, "q8iUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_s32_vg1x4, "q16iUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_u32_vg1x2, "q8UiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za32_u32_vg1x4, "q16UiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_f64_vg1x2, "q4dUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_f64_vg1x4, "q8dUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_s64_vg1x2, "q4WiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_s64_vg1x4, "q8WiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_u64_vg1x2, "q4UWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za64_u64_vg1x4, "q8UWiUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za8_s8_vg1x2, "q32ScUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za8_s8_vg1x4, "q64ScUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za8_u8_vg1x2, "q32UcUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svread_za8_u8_vg1x4, "q64UcUi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_bf16, "q8yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_f16, "q8hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_f32, "q4fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_f64, "q2dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_s16, "q8sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_s32, "q4iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_s64, "q2WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_s8, "q16ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_u16, "q8UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_u32, "q4UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_u64, "q2UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za128_u8, "q16UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_bf16, "q8yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_bf16_vg2, "q16yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_bf16_vg4, "q32yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_f16, "q8hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_f16_vg2, "q16hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_f16_vg4, "q32hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_s16, "q8sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_s16_vg2, "q16sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_s16_vg4, "q32sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_u16, "q8UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_u16_vg2, "q16UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za16_u16_vg4, "q32UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_f32, "q4fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_f32_vg2, "q8fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_f32_vg4, "q16fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_s32, "q4iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_s32_vg2, "q8iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_s32_vg4, "q16iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_u32, "q4UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_u32_vg2, "q8UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za32_u32_vg4, "q16UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_f64, "q2dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_f64_vg2, "q4dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_f64_vg4, "q8dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_s64, "q2WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_s64_vg2, "q4WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_s64_vg4, "q8WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_u64, "q2UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_u64_vg2, "q4UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za64_u64_vg4, "q8UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_s8, "q16ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_s8_vg2, "q32ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_s8_vg4, "q64ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_u8, "q16UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_u8_vg2, "q32UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_hor_za8_u8_vg4, "q64UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_bf16, "q8yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_f16, "q8hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_f32, "q4fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_f64, "q2dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_s16, "q8sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_s32, "q4iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_s64, "q2WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_s8, "q16ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_u16, "q8UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_u32, "q4UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_u64, "q2UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za128_u8, "q16UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_bf16, "q8yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_bf16_vg2, "q16yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_bf16_vg4, "q32yIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_f16, "q8hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_f16_vg2, "q16hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_f16_vg4, "q32hIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_s16, "q8sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_s16_vg2, "q16sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_s16_vg4, "q32sIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_u16, "q8UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_u16_vg2, "q16UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za16_u16_vg4, "q32UsIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_f32, "q4fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_f32_vg2, "q8fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_f32_vg4, "q16fIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_s32, "q4iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_s32_vg2, "q8iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_s32_vg4, "q16iIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_u32, "q4UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_u32_vg2, "q8UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za32_u32_vg4, "q16UiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_f64, "q2dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_f64_vg2, "q4dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_f64_vg4, "q8dIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_s64, "q2WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_s64_vg2, "q4WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_s64_vg4, "q8WiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_u64, "q2UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_u64_vg2, "q4UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za64_u64_vg4, "q8UWiIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_s8, "q16ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_s8_vg2, "q32ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_s8_vg4, "q64ScIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_u8, "q16UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_u8_vg2, "q32UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_ver_za8_u8_vg4, "q64UcIUWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_bf16_vg1x2, "q16yUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_bf16_vg1x4, "q32yUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_f16_vg1x2, "q16hUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_f16_vg1x4, "q32hUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_s16_vg1x2, "q16sUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_s16_vg1x4, "q32sUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_u16_vg1x2, "q16UsUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za16_u16_vg1x4, "q32UsUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_f32_vg1x2, "q8fUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_f32_vg1x4, "q16fUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_s32_vg1x2, "q8iUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_s32_vg1x4, "q16iUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_u32_vg1x2, "q8UiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za32_u32_vg1x4, "q16UiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_f64_vg1x2, "q4dUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_f64_vg1x4, "q8dUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_s64_vg1x2, "q4WiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_s64_vg1x4, "q8WiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_u64_vg1x2, "q4UWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za64_u64_vg1x4, "q8UWiUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za8_s8_vg1x2, "q32ScUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za8_s8_vg1x4, "q64ScUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za8_u8_vg1x2, "q32UcUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svreadz_za8_u8_vg1x4, "q64UcUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svst1_hor_vnum_za128, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_vnum_za16, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_vnum_za32, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_vnum_za64, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_vnum_za8, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_za128, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_za16, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_za32, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_za64, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_hor_za8, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_vnum_za128, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_vnum_za16, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_vnum_za32, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_vnum_za64, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_vnum_za8, "vIUWiUiq16bv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_za128, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_za16, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_za32, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_za64, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svst1_ver_za8, "vIUWiUiq16bv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svstr_vnum_za, "vUiv*Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svstr_za, "vUiv*", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svstr_zt, "vIUWiv*", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za32_s32_vg1x2, "vUiq8iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za32_s32_vg1x4, "vUiq16iq4i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za32_u32_vg1x2, "vUiq8Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za32_u32_vg1x4, "vUiq16Uiq4Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za64_s64_vg1x2, "vUiq4Wiq2Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za64_s64_vg1x4, "vUiq8Wiq2Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za64_u64_vg1x2, "vUiq4UWiq2UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_single_za64_u64_vg1x4, "vUiq8UWiq2UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_za32_s32_vg1x2, "vUiq8iq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_za32_s32_vg1x4, "vUiq16iq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_za32_u32_vg1x2, "vUiq8Uiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_za32_u32_vg1x4, "vUiq16Uiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_write_za64_s64_vg1x2, "vUiq4Wiq4Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_za64_s64_vg1x4, "vUiq8Wiq8Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_za64_u64_vg1x2, "vUiq4UWiq4UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_write_za64_u64_vg1x4, "vUiq8UWiq8UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_za16_bf16_vg1x2, "vUiq16y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svsub_za16_bf16_vg1x4, "vUiq32y", "n", "sme2,b16b16")
TARGET_BUILTIN(__builtin_sme_svsub_za16_f16_vg1x2, "vUiq16h", "n", "sme-f16f16|sme-f8f16")
TARGET_BUILTIN(__builtin_sme_svsub_za16_f16_vg1x4, "vUiq32h", "n", "sme-f16f16|sme-f8f16")
TARGET_BUILTIN(__builtin_sme_svsub_za32_f32_vg1x2, "vUiq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za32_f32_vg1x4, "vUiq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za32_s32_vg1x2, "vUiq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za32_s32_vg1x4, "vUiq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za32_u32_vg1x2, "vUiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za32_u32_vg1x4, "vUiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsub_za64_f64_vg1x2, "vUiq4d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svsub_za64_f64_vg1x4, "vUiq8d", "n", "sme2,sme-f64f64")
TARGET_BUILTIN(__builtin_sme_svsub_za64_s64_vg1x2, "vUiq4Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_za64_s64_vg1x4, "vUiq8Wi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_za64_u64_vg1x2, "vUiq4UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsub_za64_u64_vg1x4, "vUiq8UWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsudot_lane_za32_s8_vg1x2, "vUiq32Scq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsudot_lane_za32_s8_vg1x4, "vUiq64Scq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsudot_single_za32_s8_vg1x2, "vUiq32Scq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsudot_single_za32_s8_vg1x4, "vUiq64Scq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsudot_za32_s8_vg1x2, "vUiq32Scq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsudot_za32_s8_vg1x4, "vUiq64Scq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_lane_za32_s8_vg4x1, "vUiq16Scq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_lane_za32_s8_vg4x2, "vUiq32Scq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_lane_za32_s8_vg4x4, "vUiq64Scq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_single_za32_s8_vg4x2, "vUiq32Scq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_single_za32_s8_vg4x4, "vUiq64Scq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_za32_s8_vg4x1, "vUiq16Scq16Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_za32_s8_vg4x2, "vUiq32Scq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumla_za32_s8_vg4x4, "vUiq64Scq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svsumopa_za32_s8_m, "vIUWiq16bq16bq16Scq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svsumopa_za64_s16_m, "vIUWiq16bq16bq8sq8Us", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsumops_za32_s8_m, "vIUWiq16bq16bq16Scq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svsumops_za64_s16_m, "vIUWiq16bq16bq8sq8Us", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svsuvdot_lane_za32_s8_vg1x4, "vUiq64Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_lane_za32_u8_vg1x2, "vUiq32Ucq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_lane_za32_u8_vg1x4, "vUiq64Ucq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_single_za32_u8_vg1x2, "vUiq32Ucq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_single_za32_u8_vg1x4, "vUiq64Ucq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_za32_u8_vg1x2, "vUiq32Ucq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusdot_za32_u8_vg1x4, "vUiq64Ucq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_lane_za32_u8_vg4x1, "vUiq16Ucq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_lane_za32_u8_vg4x2, "vUiq32Ucq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_lane_za32_u8_vg4x4, "vUiq64Ucq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_single_za32_u8_vg4x2, "vUiq32Ucq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_single_za32_u8_vg4x4, "vUiq64Ucq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_za32_u8_vg4x1, "vUiq16Ucq16Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_za32_u8_vg4x2, "vUiq32Ucq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmla_za32_u8_vg4x4, "vUiq64Ucq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svusmopa_za32_u8_m, "vIUWiq16bq16bq16Ucq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svusmopa_za64_u16_m, "vIUWiq16bq16bq8Usq8s", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svusmops_za32_u8_m, "vIUWiq16bq16bq16Ucq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svusmops_za64_u16_m, "vIUWiq16bq16bq8Usq8s", "n", "sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svusvdot_lane_za32_u8_vg1x4, "vUiq64Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_bf16_vg1x2, "vUiq16yq8yIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_f16_vg1x2, "vUiq16hq8hIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_s16_vg1x2, "vUiq16sq8sIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_s8_vg1x4, "vUiq64Scq16ScIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_u16_vg1x2, "vUiq16Usq8UsIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za32_u8_vg1x4, "vUiq64Ucq16UcIUWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za64_s16_vg1x4, "vUiq32sq8sIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svvdot_lane_za64_u16_vg1x4, "vUiq32Usq8UsIUWi", "n", "sme2,sme-i16i64")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_bf16_m, "vIUWiUiq16bq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_f16_m, "vIUWiUiq16bq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_f32_m, "vIUWiUiq16bq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_f64_m, "vIUWiUiq16bq2d", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_s16_m, "vIUWiUiq16bq8s", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_s32_m, "vIUWiUiq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_s64_m, "vIUWiUiq16bq2Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_s8_m, "vIUWiUiq16bq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_u16_m, "vIUWiUiq16bq8Us", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_u32_m, "vIUWiUiq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_u64_m, "vIUWiUiq16bq2UWi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za128_u8_m, "vIUWiUiq16bq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_bf16_m, "vIUWiUiq16bq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_bf16_vg2, "vIUWiUiq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_bf16_vg4, "vIUWiUiq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_f16_m, "vIUWiUiq16bq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_f16_vg2, "vIUWiUiq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_f16_vg4, "vIUWiUiq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_s16_m, "vIUWiUiq16bq8s", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_s16_vg2, "vIUWiUiq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_s16_vg4, "vIUWiUiq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_u16_m, "vIUWiUiq16bq8Us", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_u16_vg2, "vIUWiUiq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za16_u16_vg4, "vIUWiUiq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_f32_m, "vIUWiUiq16bq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_f32_vg2, "vIUWiUiq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_f32_vg4, "vIUWiUiq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_s32_m, "vIUWiUiq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_s32_vg2, "vIUWiUiq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_s32_vg4, "vIUWiUiq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_u32_m, "vIUWiUiq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_u32_vg2, "vIUWiUiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za32_u32_vg4, "vIUWiUiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_f64_m, "vIUWiUiq16bq2d", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_f64_vg2, "vIUWiUiq4d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_f64_vg4, "vIUWiUiq8d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_s64_m, "vIUWiUiq16bq2Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_s64_vg2, "vIUWiUiq4Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_s64_vg4, "vIUWiUiq8Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_u64_m, "vIUWiUiq16bq2UWi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_u64_vg2, "vIUWiUiq4UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za64_u64_vg4, "vIUWiUiq8UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_s8_m, "vIUWiUiq16bq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_s8_vg2, "vIUWiUiq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_s8_vg4, "vIUWiUiq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_u8_m, "vIUWiUiq16bq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_u8_vg2, "vIUWiUiq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_hor_za8_u8_vg4, "vIUWiUiq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_bf16_m, "vIUWiUiq16bq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_f16_m, "vIUWiUiq16bq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_f32_m, "vIUWiUiq16bq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_f64_m, "vIUWiUiq16bq2d", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_s16_m, "vIUWiUiq16bq8s", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_s32_m, "vIUWiUiq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_s64_m, "vIUWiUiq16bq2Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_s8_m, "vIUWiUiq16bq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_u16_m, "vIUWiUiq16bq8Us", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_u32_m, "vIUWiUiq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_u64_m, "vIUWiUiq16bq2UWi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za128_u8_m, "vIUWiUiq16bq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_bf16_m, "vIUWiUiq16bq8y", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_bf16_vg2, "vIUWiUiq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_bf16_vg4, "vIUWiUiq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_f16_m, "vIUWiUiq16bq8h", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_f16_vg2, "vIUWiUiq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_f16_vg4, "vIUWiUiq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_s16_m, "vIUWiUiq16bq8s", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_s16_vg2, "vIUWiUiq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_s16_vg4, "vIUWiUiq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_u16_m, "vIUWiUiq16bq8Us", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_u16_vg2, "vIUWiUiq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za16_u16_vg4, "vIUWiUiq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_f32_m, "vIUWiUiq16bq4f", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_f32_vg2, "vIUWiUiq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_f32_vg4, "vIUWiUiq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_s32_m, "vIUWiUiq16bq4i", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_s32_vg2, "vIUWiUiq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_s32_vg4, "vIUWiUiq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_u32_m, "vIUWiUiq16bq4Ui", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_u32_vg2, "vIUWiUiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za32_u32_vg4, "vIUWiUiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_f64_m, "vIUWiUiq16bq2d", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_f64_vg2, "vIUWiUiq4d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_f64_vg4, "vIUWiUiq8d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_s64_m, "vIUWiUiq16bq2Wi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_s64_vg2, "vIUWiUiq4Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_s64_vg4, "vIUWiUiq8Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_u64_m, "vIUWiUiq16bq2UWi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_u64_vg2, "vIUWiUiq4UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za64_u64_vg4, "vIUWiUiq8UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_s8_m, "vIUWiUiq16bq16Sc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_s8_vg2, "vIUWiUiq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_s8_vg4, "vIUWiUiq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_u8_m, "vIUWiUiq16bq16Uc", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_u8_vg2, "vIUWiUiq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_ver_za8_u8_vg4, "vIUWiUiq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_bf16_vg1x2, "vUiq16y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_bf16_vg1x4, "vUiq32y", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_f16_vg1x2, "vUiq16h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_f16_vg1x4, "vUiq32h", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_s16_vg1x2, "vUiq16s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_s16_vg1x4, "vUiq32s", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_u16_vg1x2, "vUiq16Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za16_u16_vg1x4, "vUiq32Us", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_f32_vg1x2, "vUiq8f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_f32_vg1x4, "vUiq16f", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_s32_vg1x2, "vUiq8i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_s32_vg1x4, "vUiq16i", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_u32_vg1x2, "vUiq8Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za32_u32_vg1x4, "vUiq16Ui", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_f64_vg1x2, "vUiq4d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_f64_vg1x4, "vUiq8d", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_s64_vg1x2, "vUiq4Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_s64_vg1x4, "vUiq8Wi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_u64_vg1x2, "vUiq4UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za64_u64_vg1x4, "vUiq8UWi", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za8_s8_vg1x2, "vUiq32Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za8_s8_vg1x4, "vUiq64Sc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za8_u8_vg1x2, "vUiq32Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svwrite_za8_u8_vg1x4, "vUiq64Uc", "n", "sme2")
TARGET_BUILTIN(__builtin_sme_svzero_mask_za, "vIUWi", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svzero_za, "vv", "n", "sme")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg1x2, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg1x4, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg2x1, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg2x2, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg2x4, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg4x1, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg4x2, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_za64_vg4x4, "vUi", "n", "sme2p1")
TARGET_BUILTIN(__builtin_sme_svzero_zt, "vIUWi", "n", "sme2")
#endif

