#define CLANG_VERSION 19.1.7
#define CLANG_VERSION_STRING "19.1.7"
#define CLANG_VERSION_MAJOR 19
#define CLANG_VERSION_MAJOR_STRING "19"
#define CLANG_VERSION_MINOR 1
#define CLANG_VERSION_PATCHLEVEL 7
